==> doctorlink-design-system-1.0.32.tgz: package/es/Components/Layout/TwoColumn.js <==
import React from 'react';
import PropTypes from 'prop-types';
import styled, { css } from 'styled-components';
import * as reset from '../reset';
import FullLogo from '../Logo/Full';

const contentAlignmentCss = {
  center: css`
    align-items: center;
  `,
  top: css``
};
const fillMap = {
  screen: css`
    height: 100vh;
  `,
  height: css`
    height: 100%;
  `
};

export const DefaultContainer = reset.div`
  display: flex;
  flex-direction: row;
  ${p => fillMap[p.fill]}
  align-items: stretch;
`;

export const DefaultContentSection = reset.div`
  flex: 1;
  display: flex;
  ${p => contentAlignmentCss[p.contentAlignment]}
`;
export const DefaultContentScrollContainer = reset.div`
  width: 100%;
  display: flex;
  flex: 1;
  flex-direction: column;
  max-height: 100%;
  overflow-y: auto;
  padding-top: ${p => p.theme.layout.twoColumns.content.paddingTop}px;
  padding-bottom: ${p => p.theme.layout.twoColumns.content.paddingBottom}px;
  padding-left: ${p => p.theme.layout.twoColumns.content.paddingLeft}px;
  padding-right: ${p => p.theme.layout.twoColumns.content.paddingRight}px;
`;
export const DefaultContentContainer = reset.div`
  flex: 1;
  margin: 0 auto;
  width: 100%;
  max-width: ${p => p.theme.layout.twoColumns.content.maxWidth}px;
  min-width: ${p => p.theme.layout.twoColumns.content.minWidth}px;
`;

export const DefaultNavigationSection = reset.div`
  display: flex;
  flex-direction: column;
  width: ${p => p.theme.layout.twoColumns.navigation.width}px;
  padding-left: ${p => p.theme.layout.twoColumns.navigation.paddingLeft}px;
  padding-right: ${p => p.theme.layout.twoColumns.navigation.paddingRight}px;
  background-color: ${p => p.theme.layout.twoColumns.navigation.backgroundColor};
  border-right-color: ${p => p.theme.layout.twoColumns.navigation.borderRightColor};
  border-right-width: ${p => p.theme.layout.twoColumns.navigation.borderRightWidth}px;
  border-right-style: solid;
`;
export const DefaultNavigationHeader = reset.div`
  flex: 0;
`;
export const DefaultNavigationContent = reset.div`
  flex: 1;
  overflow: auto;
  display: flex;
  flex-direction: column;
`;
export const DefaultNavigationContentScrollContainer = reset.div`
  margin: auto 0;
`;
export const DefaultNavigationFooter = reset.div`
  flex: 0;
`;

function TwoColumns(props) {
  const {
    // Components
    Logo,
    Container,
    NavigationSection,
    ContentSection,
    ContentScrollContainer,
    ContentContainer,
    NavigationHeader,
    NavigationContentScrollContainer,
    NavigationContent,
    NavigationFooter,
    // Children
    navigationContent,
    navigationFooter,
    children,
    // Modifications
    contentAlignment,
    fill
  } = props;

  return React.createElement(
    Container,
    { fill: fill },
    React.createElement(
      NavigationSection,
      null,
      React.createElement(
        NavigationHeader,
        null,
        React.createElement(Logo, null)
      ),
      React.createElement(
        NavigationContent,
        null,
        React.createElement(
          NavigationContentScrollContainer,
          null,
          navigationContent
        )
      ),
      React.createElement(
        NavigationFooter,
        null,
        navigationFooter
      )
    ),
    React.createElement(
      ContentSection,
      { contentAlignment: contentAlignment },
      React.createElement(
        ContentScrollContainer,
        null,
        React.createElement(
          ContentContainer,
          { contentAlignment: contentAlignment },
          children
        )
      )
    )
  );
}

TwoColumns.propTypes = process.env.NODE_ENV !== "production" ? {
  Logo: PropTypes.func,
  Container: PropTypes.func,
  ContentSection: PropTypes.func,
  ContentScrollContainer: PropTypes.func,
  ContentContainer: PropTypes.func,
  NavigationSection: PropTypes.func,
  NavigationHeader: PropTypes.func,
  NavigationContentScrollContainer: PropTypes.func,
  NavigationContent: PropTypes.func,
  NavigationFooter: PropTypes.func,

  children: PropTypes.node.isRequired,
  navigationContent: PropTypes.node,
  navigationFooter: PropTypes.node,

  contentAlignment: PropTypes.oneOf[('center', 'top')],
  fill: PropTypes.oneOf([`screen`, `height`])
} : {};
TwoColumns.defaultProps = {
  Logo: FullLogo,
  Container: DefaultContainer,
  ContentSection: DefaultContentSection,
  ContentScrollContainer: DefaultContentScrollContainer,
  ContentContainer: DefaultContentContainer,
  NavigationSection: DefaultNavigationSection,
  NavigationHeader: DefaultNavigationHeader,
  NavigationContentScrollContainer: DefaultNavigationContentScrollContainer,
  NavigationContent: DefaultNavigationContent,
  NavigationFooter: DefaultNavigationFooter,

  contentAlignment: 'center',
  fill: 'screen'
};

export default TwoColumns;

==> doctorlink-design-system-1.0.39.tgz: package/es/Components/Layout/TwoColumn.js <==
import React from 'react';
import PropTypes from 'prop-types';
import { css } from 'styled-components';
import * as reset from '../reset';
import FullLogo from '../Logo/Full';

const contentAlignmentCss = {
  center: css`
    align-items: center;
  `,
  top: css``
};
const fillMap = {
  screen: css`
    height: 100vh;
  `,
  height: css`
    height: 100%;
  `
};

export const DefaultContainer = reset.div`
  display: flex;
  flex-direction: row;
  ${p => fillMap[p.fill]}
  align-items: stretch;
`;

export const DefaultContentSection = reset.div`
  flex: 1;
  display: flex;
  ${p => contentAlignmentCss[p.contentAlignment]}
`;
export const DefaultContentScrollContainer = reset.div`
  width: 100%;
  display: flex;
  flex: 1;
  flex-direction: column;
  max-height: 100%;
  overflow-y: auto;
  padding-top: ${p => p.theme.layout.twoColumns.content.paddingTop}px;
  padding-bottom: ${p => p.theme.layout.twoColumns.content.paddingBottom}px;
  padding-left: ${p => p.theme.layout.twoColumns.content.paddingLeft}px;
  padding-right: ${p => p.theme.layout.twoColumns.content.paddingRight}px;
`;
export const DefaultContentContainer = reset.div`
  flex: 1;
  margin: 0 auto;
  width: 100%;
  max-width: ${p => p.theme.layout.twoColumns.content.maxWidth}px;
  min-width: ${p => p.theme.layout.twoColumns.content.minWidth}px;
`;

export const DefaultNavigationSection = reset.div`
  display: flex;
  flex-direction: column;
  width: ${p => p.theme.layout.twoColumns.navigation.width}px;
  padding-left: ${p => p.theme.layout.twoColumns.navigation.paddingLeft}px;
  padding-right: ${p => p.theme.layout.twoColumns.navigation.paddingRight}px;
  background-color: ${p => p.theme.layout.twoColumns.navigation.backgroundColor};
  border-right-color: ${p => p.theme.layout.twoColumns.navigation.borderRightColor};
  border-right-width: ${p => p.theme.layout.twoColumns.navigation.borderRightWidth}px;
  border-right-style: solid;
`;
export const DefaultNavigationHeader = reset.div`
  flex: 0;
`;
export const DefaultNavigationContent = reset.div`
  flex: 1;
  overflow: auto;
  display: flex;
  flex-direction: column;
`;
export const DefaultNavigationContentScrollContainer = reset.div`
  margin: auto 0;
`;
export const DefaultNavigationFooter = reset.div`
  flex: 0;
`;

function TwoColumns(props) {
  const {
    // Components
    Logo,
    Container,
    NavigationSection,
    ContentSection,
    ContentScrollContainer,
    ContentContainer,
    NavigationHeader,
    NavigationContentScrollContainer,
    NavigationContent,
    NavigationFooter,
    // Children
    navigationContent,
    navigationFooter,
    children,
    // Modifications
    contentAlignment,
    fill
  } = props;

  return React.createElement(
    Container,
    { fill: fill },
    React.createElement(
      NavigationSection,
      null,
      React.createElement(
        NavigationHeader,
        null,
        React.createElement(
          'a',
          { href: '/' },
          React.createElement(Logo, null)
        )
      ),
      React.createElement(
        NavigationContent,
        null,
        React.createElement(
          NavigationContentScrollContainer,
          null,
          navigationContent
        )
      ),
      React.createElement(
        NavigationFooter,
        null,
        navigationFooter
      )
    ),
    React.createElement(
      ContentSection,
      { contentAlignment: contentAlignment },
      React.createElement(
        ContentScrollContainer,
        null,
        React.createElement(
          ContentContainer,
          { contentAlignment: contentAlignment },
          children
        )
      )
    )
  );
}

TwoColumns.propTypes = process.env.NODE_ENV !== "production" ? {
  children: PropTypes.node.isRequired,

  Container: PropTypes.func,
  contentAlignment: PropTypes.oneOf(['center', 'top']),
  ContentContainer: PropTypes.func,
  ContentScrollContainer: PropTypes.func,
  ContentSection: PropTypes.func,
  fill: PropTypes.oneOf(['screen', 'height']),
  Logo: PropTypes.func,
  navigationContent: PropTypes.node,
  NavigationContent: PropTypes.func,
  NavigationContentScrollContainer: PropTypes.func,
  navigationFooter: PropTypes.node,
  NavigationFooter: PropTypes.func,
  NavigationHeader: PropTypes.func,
  NavigationSection: PropTypes.func
} : {};

TwoColumns.defaultProps = {
  Logo: FullLogo,
  Container: DefaultContainer,
  ContentSection: DefaultContentSection,
  ContentScrollContainer: DefaultContentScrollContainer,
  ContentContainer: DefaultContentContainer,
  NavigationSection: DefaultNavigationSection,
  NavigationHeader: DefaultNavigationHeader,
  NavigationContentScrollContainer: DefaultNavigationContentScrollContainer,
  NavigationContent: DefaultNavigationContent,
  NavigationFooter: DefaultNavigationFooter,

  contentAlignment: 'center',
  fill: 'screen'
};

export default TwoColumns;
